@@ -59,12 +59,19 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include "have_fpos.h"
+#include "have_string.h"
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#include "decl.h"
+#include "have_fgetsetpos.h"
 #include "endian_calc.h"
 #include "have_offscl.h"
 #include "have_posscl.h"
 #include "have_fpos_pos.h"
 #include "alloc.h"
+#include "have_unused.h"
+#include "have_memmv.h"
 
 
 #include "banned.h"	/* include after system header <> includes */
@@ -73,7 +80,7 @@
 char *program;			/* our name */
 
 int
-main(int argc, char **argv)
+main(int UNUSED(argc), char **argv)
 {
 	int stsizelen;		/* bit length of st_size in buf */
 	int fileposlen;		/* bit length of FILEPOS */
@@ -89,7 +96,7 @@ main(int argc, char **argv)
 	/*
 	 * print the file position information
 	 */
-#if defined(HAVE_FPOS_POS)
+#if defined(HAVE_FPOS_POS) && defined(FPOS_POS_BITS)
 	fileposlen = FPOS_POS_BITS;
 #else /* ! HAVE_FPOS_POS */
 # if defined(FPOS_BITS)
@@ -107,13 +114,17 @@ main(int argc, char **argv)
 	 * Big Endian
 	 */
 	if (fileposlen == 64) {
-		printf("#define SWAP_HALF_IN_FILEPOS(dest, src)\t\t%s\n",
-		    "SWAP_HALF_IN_B64(dest, src)");
+		printf("#define SWAP_HALF_IN_FILEPOS(dest, src) \\\n"
+		       "\tSWAP_HALF_IN_B64(dest, src)\n");
 	} else if (fileposlen == 32) {
-		printf("#define SWAP_HALF_IN_FILEPOS(dest, src)\t\t%s\n",
-		    "SWAP_HALF_IN_B32(dest, src)");
+		printf("#define SWAP_HALF_IN_FILEPOS(dest, src) \\\n"
+		       "\tSWAP_HALF_IN_B32(dest, src)\n");
+	} else if (fileposlen%BASEB == 0) {
+		printf("#define SWAP_HALF_IN_FILEPOS(dest, src) \\\n"
+		       "\tswap_HALFs(dest, src, %d)\n",
+		       fileposlen/BASEB);
 	} else {
-		fprintf(stderr, "%s: unexpected FILEPOS bit size: %d\n",
+		fprintf(stderr, "%s: unexpected BIG_ENDIAN FILEPOS bit size: %d\n",
 		    program, fileposlen);
 		exit(1);
 	}
@@ -122,16 +133,15 @@ main(int argc, char **argv)
 	 * Little Endian
 	 */
 #if defined(HAVE_FILEPOS_SCALAR)
-	printf("#define SWAP_HALF_IN_FILEPOS(dest, src)\t\t%s\n",
-	    "(*(dest) = *(src))");
+	printf("#define SWAP_HALF_IN_FILEPOS(dest, src) \\\n"
+	       "\t(*(dest) = *(src))\n");
 #else /* HAVE_FILEPOS_SCALAR */
 	/*
 	 * Normally a "(*(dest) = *(src))" would do, but on some
 	 * systems a FILEPOS is not a scalar hence we must memcpy.
 	 */
-	printf("#define SWAP_HALF_IN_FILEPOS(dest, src)\t%s\n",
-	    "\\\n\tmemcpy((void *)(dest), (void *)(src), "
-	    "sizeof(FPOS_POS_LEN))");
+	printf("#define SWAP_HALF_IN_FILEPOS(dest, src) \\\n"
+	       "\tmemcpy((void *)(dest), (void *)(src), FILEPOS_LEN)\n");
 #endif /* HAVE_FILEPOS_SCALAR */
 #endif /* CALC_BYTE_ORDER == BIG_ENDIAN */
 	putchar('\n');
